You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@samza.apache.org by pm...@apache.org on 2017/10/11 20:56:28 UTC

samza git commit: SAMZA-1451: Disable integration tests conditionally in build.

Repository: samza
Updated Branches:
  refs/heads/master 24170389c -> e6eb13f85


SAMZA-1451: Disable integration tests conditionally in build.

Remove runIntegrationTests gradle property added as a part of SAMZA-1355 and introduce skipIntegrationTests property(which inverts it).
If skipIntegrationTests gradle project property is enabled, execution of all tests in samza-test project will be skipped from the build.

Author: Shanthoosh Venkataraman <sv...@linkedin.com>

Reviewers: Prateek Maheshwari <pm...@apache.org>

Closes #319 from shanthoosh/skip_integration_tests


Project: http://git-wip-us.apache.org/repos/asf/samza/repo
Commit: http://git-wip-us.apache.org/repos/asf/samza/commit/e6eb13f8
Tree: http://git-wip-us.apache.org/repos/asf/samza/tree/e6eb13f8
Diff: http://git-wip-us.apache.org/repos/asf/samza/diff/e6eb13f8

Branch: refs/heads/master
Commit: e6eb13f8525d69ae1f0736339973d31c619add17
Parents: 2417038
Author: Shanthoosh Venkataraman <sv...@linkedin.com>
Authored: Wed Oct 11 13:56:24 2017 -0700
Committer: Prateek Maheshwari <pm...@linkedin.com>
Committed: Wed Oct 11 13:56:24 2017 -0700

----------------------------------------------------------------------
 README.md                | 2 +-
 bin/check-all.sh         | 2 +-
 docs/contribute/tests.md | 2 +-
 settings.gradle          | 7 +++----
 4 files changed, 6 insertions(+), 7 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/samza/blob/e6eb13f8/README.md
----------------------------------------------------------------------
diff --git a/README.md b/README.md
index 0164dd3..334c7b4 100644
--- a/README.md
+++ b/README.md
@@ -34,7 +34,7 @@ Samza builds with [Scala](http://www.scala-lang.org/) 2.10 or 2.11 and [YARN](ht
 
 ### Testing Samza
 
-To run all unit tests:
+To run all tests:
 
     ./gradlew clean test
 

http://git-wip-us.apache.org/repos/asf/samza/blob/e6eb13f8/bin/check-all.sh
----------------------------------------------------------------------
diff --git a/bin/check-all.sh b/bin/check-all.sh
index ceb1e99..2f9f03c 100755
--- a/bin/check-all.sh
+++ b/bin/check-all.sh
@@ -81,7 +81,7 @@ do
     for yarn_version in "${YARNs[@]}"
     do
       echo "------------- Running check task against JDK${jdk_number}/Scala ${scala_version}/YARN ${yarn_version}"
-      ${gradle_file} -PscalaVersion=${scala_version} -PyarnVersion=${yarn_version} -Dorg.gradle.java.home=${!i} -PrunIntegrationTests clean check $@
+      ${gradle_file} -PscalaVersion=${scala_version} -PyarnVersion=${yarn_version} -Dorg.gradle.java.home=${!i} clean check $@
       echo "------------- Finished running check task against JDK${jdk_number}/Scala ${scala_version}/YARN ${yarn_version}"
     done
   done

http://git-wip-us.apache.org/repos/asf/samza/blob/e6eb13f8/docs/contribute/tests.md
----------------------------------------------------------------------
diff --git a/docs/contribute/tests.md b/docs/contribute/tests.md
index 048e3be..9fe728c 100644
--- a/docs/contribute/tests.md
+++ b/docs/contribute/tests.md
@@ -25,7 +25,7 @@ Samza's unit tests are written on top of [JUnit](http://junit.org/), and license
 
 To run all tests, and license checks:
 
-    ./gradlew clean check -PrunIntegrationTests
+    ./gradlew clean check
 
 To run a single test:
 

http://git-wip-us.apache.org/repos/asf/samza/blob/e6eb13f8/settings.gradle
----------------------------------------------------------------------
diff --git a/settings.gradle b/settings.gradle
index 603cd35..4c81d9c 100644
--- a/settings.gradle
+++ b/settings.gradle
@@ -48,18 +48,17 @@ rootProject.children.each {
 }
 
 /**
  * Skips execution of all integration tests in project 'samza-test'.
  * To run integration tests in samza-test: './gradlew clean build -PrunIntegrationTests'
  */
 gradle.taskGraph.whenReady { taskGraph ->
   taskGraph.getAllTasks().each { task ->
     def project = task.getProject()
     task.onlyIf {
       /**
        * Behaves as pass through filter for all tasks when `runIntegrationTests` property is turned on.
        * Filters 'test' task of 'samza-test' project otherwise.
        */
-      project.hasProperty("runIntegrationTests") || !(project.getName().contains("samza-test") && task.getName() == "test")
+      !project.hasProperty("skipIntegrationTests") || !(project.getName().contains("samza-test") && task.getName() == "test")
     }
   }
 }
@@ -48,18 +48,17 @@ rootProject.children.each {
 
 /**
- * Skips execution of all integration tests in project 'samza-test'.
- * To run integration tests in samza-test: './gradlew clean build -PrunIntegrationTests'
+ * To skip integration tests in samza-test: './gradlew clean build -PskipIntegrationTests'
  */
 gradle.taskGraph.whenReady { taskGraph ->
@@ -48,18 +48,17 @@ rootProject.children.each {
     task.onlyIf {
       /**
-       * Behaves as pass through filter for all tasks when `runIntegrationTests` property is turned on.
+       * Behaves as pass through filter for all tasks when `skipIntegrationTests` property is turned off.
        * Filters 'test' task of 'samza-test' project otherwise.
        */